<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class DocumentoRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->connection = $entityManager->getConnection();
    }

    public function get(
        int $nrOrg,
        int $nrAnexo
    ): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GPE_ANEXOS
            WHERE
                NRORG = :P_NRORG AND
                NRANEXO = :P_NRANEXO
SQL;

        $params = [
            'P_NRORG'   => $nrOrg,
            'P_NRANEXO' => $nrAnexo,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $documento = $std->fetch();

        return $documento;
    }

    public function getDocumentosVinculo(
        array $params
    ): array {
        $params['P_NRCATEGORIA'] =
            $params['P_NRCATEGORIA'] ??
            null;

        $sql = <<<SQL
            SELECT
                ANEX.*,
                CAT.NMCATEGDOCUMENTO,
                TIPO.NMTIPODOCUMENTO
            FROM
                GPE_VINCULOM VM
                JOIN
                GPE_PESSOA P ON
                    P.NRORG = VM.NRORG AND
                    P.NRPESSOA = VM.NRPESSOA
                JOIN
                GPE_ANEXOS ANEX ON
                    ANEX.NRORG = P.NRORG AND
                    ANEX.NRPARCNEGOCIO = P.NRPARCNEGOCIO
                LEFT JOIN
                GER_CATEGDOCUMENTO CAT ON
                    CAT.NRORG = ANEX.NRORG AND
                    CAT.NRCATEGDOCUMENTO = ANEX.NRCATEGDOCUMENTO
                LEFT JOIN
                GER_TIPODOCUMENTO TIPO ON
                    TIPO.NRORG = ANEX.NRORG AND
                    TIPO.NRTIPODOCUMENTO = ANEX.NRTIPODOCUMENTO
            WHERE
                VM.NRORG = :P_NRORG AND
                VM.NRVINCULOM = :P_NRVINCULO AND
                (
                    (
                        :P_NRCATEGORIA IS NOT NULL AND
                        ANEX.NRCATEGDOCUMENTO = :P_NRCATEGORIA
                    ) OR
                    (
                        :P_NRCATEGORIA = 'null' AND
                        ANEX.NRCATEGDOCUMENTO IS NULL
                    ) OR
                    :P_NRCATEGORIA IS NULL
                ) AND
                TIPO.IDDOCUMENTOPUBLICO = 'S'
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $documentos = $std->fetchAll();

        return $documentos;
    }

    public function getCategoriasComDocumentoVinculo(
        array $params
    ): array {
        $sql = <<<SQL
            SELECT
                CAT.NRCATEGDOCUMENTO,
                CAT.NMCATEGDOCUMENTO
            FROM
                GPE_VINCULOM VM
                JOIN
                GPE_PESSOA P ON
                    P.NRORG = VM.NRORG AND
                    P.NRPESSOA = VM.NRPESSOA
                JOIN
                GPE_ANEXOS ANEX ON
                    ANEX.NRORG = P.NRORG AND
                    ANEX.NRPARCNEGOCIO = P.NRPARCNEGOCIO
                LEFT JOIN
                GER_CATEGDOCUMENTO CAT ON
                    CAT.NRORG = ANEX.NRORG AND
                    CAT.NRCATEGDOCUMENTO = ANEX.NRCATEGDOCUMENTO
                LEFT JOIN
                GER_TIPODOCUMENTO TIPO ON
                    TIPO.NRORG = ANEX.NRORG AND
                    TIPO.NRTIPODOCUMENTO = ANEX.NRTIPODOCUMENTO
            WHERE
                VM.NRORG = :P_NRORG AND
                VM.NRVINCULOM = :P_NRVINCULO
            GROUP BY
                CAT.NRCATEGDOCUMENTO,
                CAT.NMCATEGDOCUMENTO
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $categorias = $std->fetchAll();

        return $categorias;
    }

    public function getCategorias(
        array $params
    ): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GER_CATEGDOCUMENTO
            WHERE
                IDATIVO = 'S' AND
                NRORG = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $categorias = $std->fetchAll();

        return $categorias;
    }

    public function getTipos(
        array $params
    ): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GER_TIPODOCUMENTO
            WHERE
                IDATIVO = 'S' AND
                NRORG = :P_NRORG AND
                IDDOCUMENTOPUBLICO = 'S'
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $tipos = $std->fetchAll();

        return $tipos;
    }

    public function saveDocumento(
        array $params
    ) {
        $sql = <<<SQL
            INSERT INTO GPE_ANEXOS
            (
                NRANEXO,            NRORG,              NRPARCNEGOCIO,
                NMANEXO,            DSREFERENCIA,       IDTYPE,
                DSPATH,             DTINCLUSAO,         CDOPERINCLUSAO,
                IDFOTO,             NRCATEGDOCUMENTO,   NRTIPODOCUMENTO
            )
            VALUES
            (
                :NRANEXO,           :NRORG,             :NRPARC,
                :NMANEXO,           :DSREFERENCIA,      :IDTYPE,
                :DSPATH,            SYSDATE,            :CDOPERINCLUSAO,
                :IDFOTO,            :NRCATEGORIA,       :NRTIPO
            )
SQL;

        $params['NMANEXO']          = $params['NMANEXO'] ?? $params['DSREFERENCIA'];
        $params['IDTYPE']           = $params['IDTYPE'] ?? 'image/jpeg';
        $params['CDOPERINCLUSAO']   = $params['CDOPERINCLUSAO'] ?? 1;
        $params['IDFOTO']           = $params['IDFOTO'] ?? 'S';

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}