<?php

namespace Ems\Services;

use Util\NovoCodigo;
use Util\Environment;
use Util\DateUtil;
use Ems\Util\{ ExpectedException, ArrayUtil };
use Ems\Repository\AdmissaoRepository;
use Ems\Services\OperadorService;
use Ems\Services\EstruturaService;
use \Setforms2\Shared\ORM\DateTime;

class AdmissaoService {
    /** @var Environment */
    protected $environment;

    /** @var AdmissaoRepository */
    protected $admissaoRepository;

    /** @var OperadorService */
    protected $operadorService;

    /** @var EstruturaService */
    protected $estruturaService;

    public function __construct(
        Environment         $environment,
        AdmissaoRepository  $admissaoRepository,
        OperadorService     $operadorService,
        EstruturaService    $estruturaService
    ) {
        $this->environment          = $environment;
        $this->admissaoRepository   = $admissaoRepository;
        $this->operadorService      = $operadorService;
        $this->estruturaService     = $estruturaService;
    }

    public function getVinculosNaoAprovados(
        string $cdOperador,
               $nrEstrutura
    ): array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $dtMesCompetencia = DateUtil::getPrimeiroDiaDoMes(new DateTime());
        $dtMesCompetencia = $dtMesCompetencia->format('d/m/Y');

        $isDP = $this->operadorService->operadorIsDP($cdOperador);

        $nrEstruturas = null;

        if (!$isDP) {
            $estruturas = $this->estruturaService->getEstruturasInferiores($nrEstrutura);
            $nrEstruturas = ArrayUtil::toStringSQL($estruturas);
        }

        $params = [
            'P_NRORG'           => $nrOrg,
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_DTMESCOMPETENC'  => $dtMesCompetencia,
            'P_NRESTRUTURAS'    => $nrEstruturas,
        ];

        $admissoes = $this->admissaoRepository->getVinculosNaoAprovados(
            $params
        );

        return $admissoes;
    }
}