<?php

namespace Ems\Services;

use Doctrine\ORM\EntityManager;

use Ems\Repository\ParceiroNegocioRepository;
use Ems\Services\ParamOrgService;
use Util\Repositories;
use Util\Environment;

class ParceiroNegocioService {
    
    public function __construct(EntityManager $entityManager, Environment $environment, ParamOrgService $paramOrgService, ParceiroNegocioRepository $parceiroNegocioRepository) {
        $this->entityManager                = $entityManager;
        $this->environment                  = $environment;
        $this->paramOrgService              = $paramOrgService;
        $this->parceiroNegocioRepository    = $parceiroNegocioRepository;
        
    }
    
    protected const CDFORMACOMU_EMAIL = '05';
    
    public function getParceirosNegocioPerfilAcesso(string $perfilAcesso = null) {
        $nrorg = (int) $this->environment->getNrorg();
        
        $perfilAcesso = (int) $this->paramOrgService->getPerfilAcessoOrg($perfilAcesso);
        
        $parcNegocioPerfilAcesso = [];
        
        if (!empty($perfilAcesso) || $perfilAcesso == '0') {
            $parcNegocioPerfilAcesso = $this->parceiroNegocioRepository->getParceiroNegocioByPerfilAcesso($nrorg, $perfilAcesso);
        }
        
        return $parcNegocioPerfilAcesso;
    }
    
    public function getEmailsPorPerfilAcesso() {
        $nrorg = $this->environment->getNrorg();
        $nrParcsNegocio = $this->getParceirosNegocioPerfilAcesso();
        
        $comunicaParcs = $this->entityManager->getRepository(Repositories::COMUNICAPARC)->findBy(array('nrorg' => $nrorg, 'nrparcnegocio' => $nrParcsNegocio, 'cdformacomu' => self::CDFORMACOMU_EMAIL));
        
        $comunicaParcsEmails = array_map(function($comunicaParc) { return $comunicaParc->getCdcomunicaparc(); }, $comunicaParcs);
        return $comunicaParcsEmails;
    }
    
    public function getEmailParcNegocio($nrparnegocio) {
        $nrorg = $this->environment->getNrorg();
        $comunicaParc = $this->entityManager->getRepository(Repositories::COMUNICAPARC)->findOneBy(array('nrorg' => $nrorg, 'nrparcnegocio' => $nrparnegocio, 'cdformacomu' => self::CDFORMACOMU_EMAIL));
        
        if (!empty($comunicaParc)) {
            return $comunicaParc->getCdcomunicaparc();
        }
        
        return false;
        
    }
    
    public function getComunicacaoParc($nrorg, $nrvinculom) {
         if (empty($nrorg)) {
            $nrorg = $this->environment->getNrorg();
        }
        
        $comunicaParc = $this->parceiroNegocioRepository->getComunicacaoParc($nrorg, $nrvinculom);
        
        return $comunicaParc;
    }
    
    public function getContaCorrenteParc($nrorg, $nrvinculom) {
         if (empty($nrorg)) {
            $nrorg = $this->environment->getNrorg();
        }
        
        $comunicaParc = $this->parceiroNegocioRepository->getContaCorrenteParc($nrorg, $nrvinculom);
        
        return $comunicaParc;
    }
    
    public function getEnderecoParc($nrorg, $nrvinculom) {
         if (empty($nrorg)) {
            $nrorg = $this->environment->getNrorg();
        }
        
        $comunicaParc = $this->parceiroNegocioRepository->getEnderecoParc($nrorg, $nrvinculom);
        
        return $comunicaParc;
    }
    
}