<?php

namespace Ems\Util;

class Utils {
    
    const ORDEM_ASC     = 'ASC';
    const ORDEM_DESC    = 'DESC';
    
    const DEFAULT_FLOAT_DECIMAL_FIELDS_PRECISION = 3;
    
    public static function getIdDiaSemana(string $date): string {
        $formattedDate = Utils::formatDateYMD($date);

        $dayOfWeek = date('w', strtotime($formattedDate));

        $idRelation = [
            '1000000',
            '0100000',
            '0010000',
            '0001000',
            '0000100',
            '0000010',
            '0000001',
        ];

        $idDiaSemana = $idRelation[$dayOfWeek];

        return $idDiaSemana;
    }

    public static function formatDateYMD(string $date): string {
        [$day, $month, $year] = explode('/', $date);
        $formattedDate = "{$year}-{$month}-{$day}";

        return $formattedDate;
    }

    public static function formatDateDMY(string $date): string {
        [$year, $month, $day] = explode('-', $date);
        $formattedDate = "{$day}/{$month}/{$year}";

        return $formattedDate;
    }

    public static function stringToDateTime(string $date): \DateTimeImmutable {
        $formattedDate = Utils::formatDateYMD($date);
        $dateTime = new \DateTimeImmutable($formattedDate);

        return $dateTime;
    }

    public static function addDaysToDate(string $date, int $days): string {
        $dateTime = Utils::stringToDateTime($date);
        $interval = new \DateInterval("P{$days}D");
        $newDateTime = $dateTime->add($interval);
        $newDate = $newDateTime->format('d/m/Y');

        return $newDate;
    }

    public static function subDaysFromDate(string $date, int $days): string {
        $dateTime = Utils::stringToDateTime($date);
        $interval = new \DateInterval("P{$days}D");
        $newDateTime = $dateTime->sub($interval);
        $newDate = $newDateTime->format('d/m/Y');

        return $newDate;
    }
    
    public static function areFloatsEqual($a, $b, $precision = self::DEFAULT_FLOAT_DECIMAL_FIELDS_PRECISION) {
        return abs(($a-$b)/$b) < pow(10, -1 * $precision);
    }

    public static function getSqlDateTimeString(
        string $date,
        string $time
    ): string {
        $dateTime = "$date $time:00";

        return $dateTime;
    }
}